Authors
-------

* Angeline G. Burrell - https://github.com/aburrell
* Gareth Chisham
* Jone P. Reistad - https://github.com/jpreistad
  
Contributors
------------

* Dominic Jodoin - https://github.com/cotsog
